pub struct EncryptionConfig {
pub enabled: bool,
pub passphrase: Option<String>,
pub env_var: Option<String>,
}Expand description
Encryption configuration
Fields
enabled: boolWhether encryption is enabled
passphrase: Option<String>Passphrase for encryption/decryption (if enabled)
env_var: Option<String>Environment variable name to read passphrase from
Implementations
Sourceimpl EncryptionConfig
impl EncryptionConfig
Sourcepub fn new(passphrase: String) -> EncryptionConfig
pub fn new(passphrase: String) -> EncryptionConfig
Create a new encryption config with the given passphrase
Sourcepub fn from_env(env_var: String) -> EncryptionConfig
pub fn from_env(env_var: String) -> EncryptionConfig
Create a new encryption config that reads passphrase from environment variable