pub enum RegistryPropagationModel {
Unknown,
ApiAndSparseIndex,
}Expand description
How Shipper expects a registry to propagate newly published packages.
Variants
Unknown
No registry-specific propagation model is known.
ApiAndSparseIndex
The registry exposes both an HTTP API and sparse index path that can be checked for visibility.