pub fn update_state(
st: &mut ExecutionState,
state_dir: &Path,
key: &str,
new_state: PackageState,
) -> Result<()>Expand description
Update a package state and persist the entire execution state to disk.
pub fn update_state(
st: &mut ExecutionState,
state_dir: &Path,
key: &str,
new_state: PackageState,
) -> Result<()>Update a package state and persist the entire execution state to disk.