fsync_parent_dir

Function fsync_parent_dir 

pub fn fsync_parent_dir(path: &Path)
Best-effort fsync of the parent directory after a rename, ensuring the directory entry update is durable on crash. Errors are silently ignored because not all platforms support opening a directory for sync (e.g. Windows).